@@ -4,7 +4,7 @@ import gtk.glade
 import gobject
 import traceback
 from gettext import gettext as _
-from os.path import join, isdir
+from os.path import join
 import deskbar
 from deskbar.core.updater.NewStuffUpdater import NewStuffUpdater
 from deskbar.core.ModuleList import WebModuleList
@@ -23,6 +23,7 @@ class InfoBox(gtk.HBox):
         self.info_image.set_padding(3, 0)
         self.pack_start(self.info_image, expand=False, fill=False)
         self.label = gtk.Label()
+        self.label.set_line_wrap(True)
         self.label.set_alignment(0.0, 0.5)
         self.label.set_justify(gtk.JUSTIFY_LEFT)
         self.label.set_markup(text)
@@ -41,19 +42,12 @@ class DeskbarPreferences:
         
         # Since newstuff is optional we have to check if self.newstuff is None each time we use it
         self.newstuff = None
-            
-        # Retreive current values
-        # TODO: width and expand still missing
-        #self.width = deskbar.GCONF_CLIENT.get_int(applet.prefs.GCONF_WIDTH)
-        #self.expand = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_EXPAND)
-        self.width = 20
-        self.expand = False
         
         self.keybinding = self._model.get_keybinding()
         
         self.__setup_active_modules_tab()
         
-        self.__setup_view_tab()
+        self.__setup_general_tab()
         
         # Setup Drag & Drop
         self.__setup_drag_and_drop()
@@ -68,9 +62,6 @@ class DeskbarPreferences:
         self.sync_ui()
 
     def __setup_active_modules_tab(self):
-        # List of modules
-        self.module_list.connect ("rows-reordered", lambda a,b,c,d: self.update_gconf())
-        
         container = self.glade.get_widget("handlers")
         self.moduleview = ModuleListView(self.module_list)
         self.moduleview.connect ("row-toggled", self.on_module_toggled)
@@ -102,29 +93,12 @@ class DeskbarPreferences:
         self.button_bottom = self.glade.get_widget("button_bottom")
         self.button_bottom.connect("clicked", self.on_button_bottom_clicked)
 
-    def __setup_view_tab(self):
-        self.width_spin = self.glade.get_widget("width")
-        self.width_spin.connect('value-changed', self.on_spin_width_change)
-
-        self.use_all_width_radio = self.glade.get_widget("use_all_width_radio")
-        #self.use_all_width_radio.connect('toggled', self.on_use_all_width_radio_toggle, applet)
-        #self.expand_notify_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_EXPAND, lambda x, y, z, a: self.on_config_expand(z.value))
-        self.fixed_width_radio = self.glade.get_widget("fixed_width_radio")
-        
+    def __setup_general_tab(self):
         self.keyboard_shortcut_entry = AccelEntry()
         self.keyboard_shortcut_entry.connect('accel-edited', self.on_keyboard_shortcut_entry_changed)
         self.glade.get_widget("keybinding_entry_container").pack_start(self.keyboard_shortcut_entry.get_widget(), False)
         #self.keybinding_notify_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_KEYBINDING, lambda x, y, z, a: self.on_config_keybinding(z.value))
         
-        self.width_units = self.glade.get_widget("width_units")
-        
-        self.ui_name = self._model.get_ui_name()
-        self.completion_ui_radio = self.glade.get_widget("completion_radio")
-        self.cuemiac_ui_radio = self.glade.get_widget("cuemiac_radio")
-        self.completion_ui_radio.connect ("toggled", self.on_ui_changed)
-        self.cuemiac_ui_radio.connect ("toggled", self.on_ui_changed)
-        #self.ui_change_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_UI_NAME, lambda x, y, z, a: self.on_config_ui(z.value))
-        
         self.use_selection = self._model.get_use_selection()
         self.use_selection_box = self.glade.get_widget("use_selection")
         self.use_selection_box.connect('toggled', self.on_use_selection_toggled)
@@ -213,73 +187,29 @@ class DeskbarPreferences:
         self.moduleview.grab_focus()
         self.dialog.connect("response", self.on_dialog_response)
     
-    def on_dialog_response(self, dialog, response):    
+    def on_dialog_response(self, dialog, response):
+        self.update_gconf()    
         self.dialog.destroy()
         if self.newstuff != None:
             self.newstuff.close()
         
     def sync_ui(self):
-        if self.expand:
-            self.use_all_width_radio.set_active(True)
-        else:
-            self.fixed_width_radio.set_active(True)
-            
-        self.width_spin.set_value(self.width)
-        
         if self.keybinding != None:
             self.keyboard_shortcut_entry.set_accelerator_name(self.keybinding)
         else:
             self.keyboard_shortcut_entry.set_accelerator_name("<Alt>F3")
         
-#        if self.ui_name == ENTRIAC_UI_NAME:
-#            self.completion_ui_radio.set_active (True)
-#            self.set_width_settings_sensitive(True)
-#        elif self.ui_name == CUEMIAC_UI_NAME:
-#            self.cuemiac_ui_radio.set_active (True)
-#            self.set_width_settings_sensitive(False)
-#        elif self.ui_name == WINDOW_UI_NAME:
-#            self.cuemiac_ui_radio.set_active (True)
-#            self.set_ui_settings_sensitive(False)
-#            self.set_width_settings_sensitive(False)
-        self.cuemiac_ui_radio.set_active (True)
-        self.set_ui_settings_sensitive(False)
-        self.set_width_settings_sensitive(False)
-        
         self.use_selection_box.set_active(self.use_selection)
-            
-    def set_width_settings_sensitive(self, sensitive):
-        if sensitive and not self.expand:
-            self.width_spin.set_sensitive(True)
-            self.width_units.set_sensitive(True)
-        else:
-            self.width_spin.set_sensitive(False)
-            self.width_units.set_sensitive(False)
-            
-        self.use_all_width_radio.set_sensitive(sensitive)
-        self.fixed_width_radio.set_sensitive(sensitive)
-
-    def set_ui_settings_sensitive(self, sensitive):
-        self.cuemiac_ui_radio.set_sensitive(sensitive)
-        self.completion_ui_radio.set_sensitive(sensitive)
-            
-    def on_ui_changed (self, sender):
-#        if self.ui_name == WINDOW_UI_NAME:
-#            # You cannot change to or from window ui
-#            return
-#        if self.completion_ui_radio.get_active ():
-#            deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_UI_NAME, ENTRIAC_UI_NAME)
-#        elif self.cuemiac_ui_radio.get_active ():
-#            deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_UI_NAME, CUEMIAC_UI_NAME)
-        pass
-            
-    def on_use_all_width_radio_toggle(self, toggle):
-        #deskbar.GCONF_CLIENT.set_bool(applet.prefs.GCONF_EXPAND, toggle.get_property('active'))
-        pass
+   
+    def on_hide_after_action_toggled(self, toggle):
+        self._model.set_hide_after_action(toggle.get_active())
         
-    def on_spin_width_change(self, spinner):
-        #deskbar.GCONF_CLIENT.set_int(applet.prefs.GCONF_WIDTH, int(spinner.get_value()))
-        pass
-    
+    def on_typingdelay_value_changed(self, spinbutton):
+        self._model.set_type_delay(spinbutton.get_value())
+        
+    def on_max_history_items_changed(self, spinbutton):
+        self._model.set_max_history_items(spinbutton.get_value())
+            
     def on_keyboard_shortcut_entry_changed(self, entry, accel_name, keyval, mods, keycode):        
         if accel_name != "":
             self._model.set_keybinding(accel_name)
@@ -425,7 +355,7 @@ class DeskbarPreferences:
     def on_install_handler(self, button):
         # Install the selected new handler
         mod_id = self.webmoduleview.get_selected_module_id()
-        if module != None:
+        if mod_id != None:
             if self.newstuff != None:
                 self.newstuff.install_module(mod_id)
             button.set_sensitive(False)
